Issue #16714: use 'raise' exceptions, don't 'throw'.
Patch by Serhiy Storchaka.
diff --git a/Lib/unittest/case.py b/Lib/unittest/case.py
index 7017e9f..6257936 100644
--- a/Lib/unittest/case.py
+++ b/Lib/unittest/case.py
@@ -447,10 +447,10 @@
def assertRaises(self, excClass, callableObj=None, *args, **kwargs):
"""Fail unless an exception of class excClass is thrown
by callableObj when invoked with arguments args and keyword
arguments kwargs. If a different type of exception is
- thrown, it will not be caught, and the test case will be
+ raised, it will not be caught, and the test case will be
deemed to have suffered an error, exactly as for an
unexpected exception.
@@ -447,10 +447,10 @@
def assertRaises(self, excClass, callableObj=None, *args, **kwargs):
- """Fail unless an exception of class excClass is thrown
+ """Fail unless an exception of class excClass is raised
by callableObj when invoked with arguments args and keyword
arguments kwargs. If a different type of exception is